AutoArchive — AutoArchive Developer Manual (ver. 1.2.1)

### Navigation

- index
- modules |
- next |
- previous |
- AutoArchive Developer Manual (ver. 1.2.1) »
- API Reference »

# AutoArchive

A simple backup utility.

This package does not provide any public library (API) intended to be imported by 3rd-party programs. All its content and content of its subpackages is the implementation of AutoArchive utility.

## Sub-Packages

- AutoArchive._application
- AutoArchive._infrastructure
- AutoArchive._services
- AutoArchive._ui

## Modules

### starter

Initializes the application and starts it.

class `AutoArchive.starter.` `Starter`

  Bases: `builtins.object`

  Fires up the show.

  classmethod `start`()

    Initializes and starts the program.

### _meta

`_Meta` class.

class `AutoArchive._meta.` `_Meta`

  Bases: `builtins.object`

  Defines various project metadata like version, license etc.

  `COPYRIGHT` = 'Copyright (C) 2003 - 2015 Robert Cernansky'
  `DESCRIPTION` = 'A simple backup utility.'
  `LICENSE` = 'This program is free software: you can redistribute it and/or modify it under\nthe terms of the GNU General Public License version 3 as published by the Free\nSoftware Foundation.\n\nThis program is distributed in the hope that it will be useful, but WITHOUT ANY\nWARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR\nA PARTICULAR PURPOSE. See the GNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License along with\nthis program. If not, see <http://www.gnu.org/licenses/>.'
  `PACKAGE_NAME` = 'autoarchive'
  `VERSION` = '1.2.1'

### Navigation

- index
- modules |
- next |
- previous |
- AutoArchive Developer Manual (ver. 1.2.1) »
- API Reference »